### Usage
```
extract_event_counts(
    events STRING
)
```

`events` - A comma-separated events string,
where each event is represented as a string
of unicode chars.

### Example
See [this dashboard](https://sql.telemetry.mozilla.org/dashboard/fenix-events)
for example usage.
